Method for converting openaq_manufacturers_list to data frame.
Source:R/manufacturers.R
as.data.frame.openaq_manufacturers_list.RdMethod for converting openaq_manufacturers_list to data frame.
Usage
# S3 method for class 'openaq_manufacturers_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)Arguments
- x
A list of manufacturers as returned from list_manufacturers.
- row.names
NULLor a character vector giving the row names for the data frame. Missing values are not allowed.- optional
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method.
- ...
additional arguments to be passed to or from methods.
Value
A data frame class of the manufacturers results, with the following columns:
- id
Numeric. The manufacturers identifier.
- name
Character. The name of the manufacturer.
- instrument_ids
Character. A comma delimited list of instrument identifiers manufactured by the manufacturer.
- instrument_names
Character. A comma delimited list of instrument names manufactured by this manufacturer.
The data frame also includes a meta attribute from the original
openaq_manufacturers_list.
Examples
if (FALSE) { # interactive()
manufacturers <- list_manufacturers(as_data_frame = FALSE)
as.data.frame(manufacturers)
}