Get a single country from countries resource.
Usage
get_country(
countries_id,
as_data_frame = TRUE,
dry_run = FALSE,
api_key = NULL
)
Arguments
- countries_id
An integer representing the OpenAQ countries_id.
- as_data_frame
A logical for toggling whether to return results as
data frame or list, default is TRUE.
- dry_run
A logical for toggling a dry run of the request, default is
FALSE.
- api_key
A valid OpenAQ API key string, default is NULL.
Value
A data frame or list of the results.
Examples
if (FALSE) { # interactive()
country <- get_country(42)
}