Skip to contents

Provides an interface to the 'OpenAQ' API https://openaq.org/, a platform for real-time and historical air quality data from around the world. Users can retrieve measurement data, metadata for sensors and locations for air quality research and monitoring.

Author

Maintainer: Russ Biggs russ@openaq.org (ORCID)

Authors:

Other contributors:

  • Francesca Mills [contributor]

  • OpenAQ dev@openaq.org [copyright holder, funder]